# Author:码思客-木森
# WeChart:musen9111
from musktest.core.tools import *
from hooks.db_check_hook import *
from hooks.fixture_hook import *


def rand_phone():
    return random_mobile()


def get_sign(a,b):
    return get_timestamp()
